@@ -5,7 +5,6 @@ from .batch_repeat_lazy_tensor import BatchRepeatLazyTensor
 from .block_diag_lazy_tensor import BlockDiagLazyTensor
 from .block_interleaved_lazy_tensor import BlockInterleavedLazyTensor
 from .block_lazy_tensor import BlockLazyTensor
-from .cached_cg_lazy_tensor import CachedCGLazyTensor
 from .cat_lazy_tensor import CatLazyTensor, cat
 from .chol_lazy_tensor import CholLazyTensor
 from .constant_mul_lazy_tensor import ConstantMulLazyTensor
@@ -13,15 +12,22 @@ from .diag_lazy_tensor import ConstantDiagLazyTensor, DiagLazyTensor
 from .interpolated_lazy_tensor import InterpolatedLazyTensor
 from .keops_lazy_tensor import KeOpsLazyTensor
 from .kronecker_product_added_diag_lazy_tensor import KroneckerProductAddedDiagLazyTensor
-from .kronecker_product_lazy_tensor import KroneckerProductLazyTensor, KroneckerProductTriangularLazyTensor
+from .kronecker_product_lazy_tensor import (
+    KroneckerProductDiagLazyTensor,
+    KroneckerProductLazyTensor,
+    KroneckerProductTriangularLazyTensor,
+)
 from .lazy_evaluated_kernel_tensor import LazyEvaluatedKernelTensor
 from .lazy_tensor import LazyTensor, delazify
+from .low_rank_root_added_diag_lazy_tensor import LowRankRootAddedDiagLazyTensor
+from .low_rank_root_lazy_tensor import LowRankRootLazyTensor
 from .matmul_lazy_tensor import MatmulLazyTensor
 from .mul_lazy_tensor import MulLazyTensor
 from .non_lazy_tensor import NonLazyTensor, lazify
 from .psd_sum_lazy_tensor import PsdSumLazyTensor
 from .root_lazy_tensor import RootLazyTensor
 from .sum_batch_lazy_tensor import SumBatchLazyTensor
+from .sum_kronecker_lazy_tensor import SumKroneckerLazyTensor
 from .sum_lazy_tensor import SumLazyTensor
 from .toeplitz_lazy_tensor import ToeplitzLazyTensor
 from .triangular_lazy_tensor import TriangularLazyTensor
@@ -38,7 +44,6 @@ __all__ = [
     "BlockLazyTensor",
     "BlockDiagLazyTensor",
     "BlockInterleavedLazyTensor",
-    "CachedCGLazyTensor",
     "CatLazyTensor",
     "CholLazyTensor",
     "ConstantDiagLazyTensor",
@@ -48,7 +53,11 @@ __all__ = [
     "KeOpsLazyTensor",
     "KroneckerProductLazyTensor",
     "KroneckerProductAddedDiagLazyTensor",
+    "KroneckerProductDiagLazyTensor",
     "KroneckerProductTriangularLazyTensor",
+    "SumKroneckerLazyTensor",
+    "LowRankRootAddedDiagLazyTensor",
+    "LowRankRootLazyTensor",
     "MatmulLazyTensor",
     "MulLazyTensor",
     "NonLazyTensor",
