@@ -24,14 +24,7 @@ from ..utils.deprecation import _deprecate_renamed_methods
 from ..utils.errors import CachingError
 from ..utils.getitem import _compute_getitem_size, _convert_indices_to_tensors, _is_noop_index, _noop_index
 from ..utils.lanczos import _postprocess_lanczos_root_inv_decomp
-from ..utils.memoize import (
-    _is_in_cache_ignore_all_args,
-    _is_in_cache_ignore_args,
-    add_to_cache,
-    cached,
-    get_from_cache,
-    pop_from_cache,
-)
+from ..utils.memoize import _is_in_cache_ignore_all_args, _is_in_cache_ignore_args, add_to_cache, cached, pop_from_cache
 from ..utils.pinverse import stable_pinverse
 from ..utils.pivoted_cholesky import pivoted_cholesky
 from ..utils.warnings import NumericalWarning
@@ -601,8 +594,7 @@ class LazyTensor(ABC):
         Returns:
             (Tensor or LazyTensor): The root of the root decomposition
         """
-        func = RootDecomposition()
-        res, _ = func.apply(
+        res, _ = RootDecomposition.apply(
             self.representation_tree(),
             self._root_decomposition_size(),
             self.dtype,
@@ -639,8 +631,7 @@ class LazyTensor(ABC):
         """
         from .root_lazy_tensor import RootLazyTensor
 
-        func = RootDecomposition()
-        roots, inv_roots = func.apply(
+        roots, inv_roots = RootDecomposition.apply(
             self.representation_tree(),
             self._root_decomposition_size(),
             self.dtype,
@@ -898,6 +889,7 @@ class LazyTensor(ABC):
         # compute p = M B and take its SVD
         pvector = current_inv_root.matmul(low_rank_mat)
         # USV^T = p; when p is a vector this saves us the trouble of computing an orthonormal basis
+        pvector = delazify(pvector)
         U, S, _ = torch.svd(pvector, some=False)
 
         # we want the root decomposition of I_r + U S^2 U^T but S is q so we need to pad.
@@ -1339,8 +1331,7 @@ class LazyTensor(ABC):
 
             return MatmulLazyTensor(self, other)
 
-        func = Matmul()
-        return func.apply(self.representation_tree(), other, *self.representation())
+        return Matmul.apply(self.representation_tree(), other, *self.representation())
 
     @property
     def matrix_shape(self):
@@ -1575,8 +1566,7 @@ class LazyTensor(ABC):
         if method == "lanczos":
             from ..lazy import lazify
 
-            func = Diagonalization()
-            evals, evecs = func.apply(
+            evals, evecs = Diagonalization.apply(
                 self.representation_tree(),
                 self.device,
                 self.dtype,
@@ -1589,9 +1579,28 @@ class LazyTensor(ABC):
 
         elif method == "symeig":
             evals, evecs = self.symeig(eigenvectors=True)
+        else:
+            raise RuntimeError(f"Unknown diagonalization method '{method}'")
 
         return evals, evecs
 
+    def _choose_root_method(self) -> str:
+        # When method is not specified,
+        # better inform which root_decomposition or root_inv_decomposition
+        # method to use based on available caches and matrix size.
+        if _is_in_cache_ignore_all_args(self, "symeig"):
+            return "symeig"
+        if _is_in_cache_ignore_all_args(self, "diagonalization"):
+            return "diagonalization"
+        if _is_in_cache_ignore_all_args(self, "lanczos"):
+            return "lanczos"
+        if (
+            self.size(-1) <= settings.max_cholesky_size.value()
+            or settings.fast_computations.covar_root_decomposition.off()
+        ):
+            return "cholesky"
+        return "lanczos"
+
     @cached(name="root_decomposition")
     def root_decomposition(self, method: Optional[str] = None):
         """
@@ -1602,66 +1611,48 @@ class LazyTensor(ABC):
         from .chol_lazy_tensor import CholLazyTensor
         from .root_lazy_tensor import RootLazyTensor
 
-        # no need to do extra work if we already have a cached cholesky decomposition
-        # TODO: Resolve issues related to triangular tensor instantiation
-        # if _is_in_cache_ignore_args(self, "cholesky"):
-        #     res = self.cholesky()
-        #     return CholLazyTensor(res)
-
         if not self.is_square:
             raise RuntimeError(
                 "root_decomposition only operates on (batches of) square (symmetric) LazyTensors. "
                 "Got a {} of size {}.".format(self.__class__.__name__, self.size())
             )
 
+        if self.shape[-2:].numel() == 1:
+            return RootLazyTensor(self.evaluate().sqrt())
+
         if method is None:
-            if (
-                self.size(-1) <= settings.max_cholesky_size.value()
-                or settings.fast_computations.covar_root_decomposition.off()
-            ):
-                method = "cholesky"
-            else:
-                method = "lanczos"
+            method = self._choose_root_method()
 
         if method == "cholesky":
+            # self.cholesky will hit cache if available
             try:
                 res = self.cholesky()
                 return CholLazyTensor(res)
             except RuntimeError as e:
                 warnings.warn(
-                    f"Runtime Error when computing Cholesky decomposition: {e}. Using RootDecomposition.".format(e),
-                    NumericalWarning,
+                    f"Runtime Error when computing Cholesky decomposition: {e}. Using symeig method.", NumericalWarning,
                 )
                 method = "symeig"
 
         if method == "pivoted_cholesky":
-            return RootLazyTensor(pivoted_cholesky(self.evaluate(), max_iter=self._root_decomposition_size()))
-
-        if method == "symeig":
+            root = pivoted_cholesky(self.evaluate(), max_iter=self._root_decomposition_size())
+        elif method == "symeig":
             evals, evecs = self.symeig(eigenvectors=True)
             # TODO: only use non-zero evals (req. dealing w/ batches...)
-            F = evecs * evals.clamp(0.0).sqrt().unsqueeze(-2)
-            return RootLazyTensor(F)
-
-        if method == "svd":
+            root = evecs * evals.clamp_min(0.0).sqrt().unsqueeze(-2)
+        elif method == "diagonalization":
+            evals, evecs = self.diagonalization()
+            root = evecs * evals.clamp_min(0.0).sqrt().unsqueeze(-2)
+        elif method == "svd":
             U, S, _ = self.svd()
             # TODO: only use non-zero singular values (req. dealing w/ batches...)
-            F = U * S.sqrt().unsqueeze(-2)
-            return RootLazyTensor(F)
+            root = U * S.sqrt().unsqueeze(-2)
+        elif method == "lanczos":
+            root = self._root_decomposition()
+        else:
+            raise RuntimeError(f"Unknown root decomposition method '{method}'")
 
-        if method == "lanczos":
-            # check to see if we have already run lanczos for a diagonalization
-            try:
-                evals, evecs = get_from_cache(self, "diagonalization")
-                F = evecs * evals.clamp(1e-7).sqrt().unsqueeze(-2)
-                return RootLazyTensor(F)
-            except CachingError:
-                pass
-
-            # if not run standard lanczos
-            return RootLazyTensor(self._root_decomposition())
-
-        raise RuntimeError(f"Unknown method '{method}'")
+        return RootLazyTensor(root)
 
     @cached(name="root_inv_decomposition")
     def root_inv_decomposition(self, initial_vectors=None, test_vectors=None, method: Optional[str] = None):
@@ -1673,57 +1664,28 @@ class LazyTensor(ABC):
         from .root_lazy_tensor import RootLazyTensor
         from .non_lazy_tensor import lazify
 
-        if self.shape[-2:].numel() == 1:
-            return RootLazyTensor(1 / self.evaluate().sqrt())
-
-        # no need to do extra work if we already have a cached cholesky decomposition
-        # TODO: Resolve issues related to triangular tensor instantiation \
-        # if _is_in_cache_ignore_args(self, "cholesky"):
-        #     res = self.cholesky()
-        #     return CholLazyTensor(res).inverse()
-
-        if method is None:
-            if (
-                self.size(-1) <= settings.max_cholesky_size.value()
-                or settings.fast_computations.covar_root_decomposition.off()
-            ):
-                method = "cholesky"
-            else:
-                method = "lanczos"
-
-        if method == "cholesky":
-            try:
-                L = delazify(self.cholesky())
-                # we know L is triangular, so inverting is a simple triangular solve agaist the identity
-                # we don't need the batch shape here, thanks to broadcasting
-                Eye = torch.eye(L.shape[-2], device=L.device, dtype=L.dtype)
-                Linv = torch.triangular_solve(Eye, L, upper=False)[0]
-                res = lazify(Linv.transpose(-1, -2))
-                return RootLazyTensor(res)
-                # L = self.cholesky()
-                # return CholLazyTensor(L).inverse()
-            except RuntimeError as e:
-                warnings.warn(
-                    "Runtime Error when computing Cholesky decomposition: {}. Using RootDecomposition.".format(e),
-                    NumericalWarning,
-                )
-
         if not self.is_square:
             raise RuntimeError(
                 "root_inv_decomposition only operates on (batches of) square (symmetric) LazyTensors. "
                 "Got a {} of size {}.".format(self.__class__.__name__, self.size())
             )
 
-        # check to see if we have already run lanczos for a diagonalization
-        try:
-            evals, evecs = get_from_cache(self, "diagonalization")
-            F = evecs * evals.clamp(1e-7).sqrt().reciprocal().unsqueeze(-2)
-            return RootLazyTensor(F)
-        except CachingError:
-            pass
+        if self.shape[-2:].numel() == 1:
+            return RootLazyTensor(1 / self.evaluate().sqrt())
 
-        # otherwise run lanczos
-        if method == "lanczos":
+        if method is None:
+            method = self._choose_root_method()
+
+        if method == "cholesky":
+            # self.cholesky will hit cache if available
+            L = delazify(self.cholesky())
+            # we know L is triangular, so inverting is a simple triangular solve agaist the identity
+            # we don't need the batch shape here, thanks to broadcasting
+            Eye = torch.eye(L.shape[-2], device=L.device, dtype=L.dtype)
+            Linv = torch.triangular_solve(Eye, L, upper=False).solution
+            res = lazify(Linv.transpose(-1, -2))
+            inv_root = res
+        elif method == "lanczos":
             if initial_vectors is not None:
                 if self.dim() == 2 and initial_vectors.dim() == 1:
                     if self.shape[-1] != initial_vectors.numel():
@@ -1747,21 +1709,23 @@ class LazyTensor(ABC):
             inv_root = self._root_inv_decomposition(initial_vectors)
             if initial_vectors is not None and initial_vectors.size(-1) > 1:
                 inv_root = _postprocess_lanczos_root_inv_decomp(self, inv_root, initial_vectors, test_vectors)
-
-        if method == "symeig":
+        elif method == "symeig":
             evals, evecs = self.symeig(eigenvectors=True)
             # TODO: only use non-zero evals (req. dealing w/ batches...)
-            inv_root = evecs * evals.clamp(1e-7).reciprocal().sqrt().unsqueeze(-2)
-
-        if method == "svd":
+            inv_root = evecs * evals.clamp_min(1e-7).reciprocal().sqrt().unsqueeze(-2)
+        elif method == "diagonalization":
+            evals, evecs = self.diagonalization()
+            inv_root = evecs * evals.clamp_min(1e-7).reciprocal().sqrt().unsqueeze(-2)
+        elif method == "svd":
             U, S, _ = self.svd()
             # TODO: only use non-zero singular values (req. dealing w/ batches...)
-            inv_root = U * S.clamp(1e-7).reciprocal().sqrt().unsqueeze(-2)
-
-        if method == "pinverse":
+            inv_root = U * S.clamp_min(1e-7).reciprocal().sqrt().unsqueeze(-2)
+        elif method == "pinverse":
             # this is numerically unstable and should rarely be used
             root = self.root_decomposition().root.evaluate()
             inv_root = torch.pinverse(root).transpose(-1, -2)
+        else:
+            raise RuntimeError(f"Unknown root inv decomposition method '{method}'")
 
         return RootLazyTensor(inv_root)
 
@@ -1796,7 +1760,7 @@ class LazyTensor(ABC):
             rhs = rhs.unsqueeze(-1)
             squeeze = True
 
-        func = SqrtInvMatmul()
+        func = SqrtInvMatmul
         sqrt_inv_matmul_res, inv_quad_res = func.apply(self.representation_tree(), rhs, lhs, *self.representation())
 
         if squeeze:
@@ -2041,7 +2005,7 @@ class LazyTensor(ABC):
         elif isinstance(other, DiagLazyTensor):
             return AddedDiagLazyTensor(self, other)
         elif isinstance(other, RootLazyTensor):
-            return self.add_low_rank(self, other.root)
+            return self.add_low_rank(other.root)
         elif isinstance(other, Tensor):
             other = lazify(other)
             shape = _mul_broadcast_shape(self.shape, other.shape)
